summaryrefslogtreecommitdiffstats
path: root/ksvg/impl/SVGAnimationElementImpl.cc
diff options
context:
space:
mode:
Diffstat (limited to 'ksvg/impl/SVGAnimationElementImpl.cc')
-rw-r--r--ksvg/impl/SVGAnimationElementImpl.cc36
1 files changed, 18 insertions, 18 deletions
diff --git a/ksvg/impl/SVGAnimationElementImpl.cc b/ksvg/impl/SVGAnimationElementImpl.cc
index 3fd29d1e..9fbab696 100644
--- a/ksvg/impl/SVGAnimationElementImpl.cc
+++ b/ksvg/impl/SVGAnimationElementImpl.cc
@@ -84,8 +84,8 @@ double SVGAnimationElementImpl::parseClockValue(const TQString &data) const
double result;
- int doublePointOne = parse.tqfind(':');
- int doublePointTwo = parse.tqfind(':', doublePointOne + 1);
+ int doublePointOne = parse.find(':');
+ int doublePointTwo = parse.find(':', doublePointOne + 1);
if(doublePointOne != -1 && doublePointTwo != -1) // Spec: "Full clock values"
{
@@ -96,7 +96,7 @@ double SVGAnimationElementImpl::parseClockValue(const TQString &data) const
result = (3600 * hours) + (60 * minutes) + seconds;
- if(parse.tqfind('.') != -1)
+ if(parse.find('.') != -1)
{
TQString temp = parse.mid(9, 2);
milliseconds = temp.toUInt();
@@ -111,7 +111,7 @@ double SVGAnimationElementImpl::parseClockValue(const TQString &data) const
result = (60 * minutes) + seconds;
- if(parse.tqfind('.') != -1)
+ if(parse.find('.') != -1)
{
TQString temp = parse.mid(6, 2);
milliseconds = temp.toUInt();
@@ -120,7 +120,7 @@ double SVGAnimationElementImpl::parseClockValue(const TQString &data) const
}
else // Spec: "Timecount values"
{
- int dotPosition = parse.tqfind('.');
+ int dotPosition = parse.find('.');
if(parse.endsWith("h"))
{
@@ -304,34 +304,34 @@ void SVGAnimationElementImpl::putValueProperty(ExecState *exec, int token, const
}
else if(current.startsWith("wallclock"))
{
- int firstBrace = current.tqfind("(");
- int secondBrace = current.tqfind(")");
+ int firstBrace = current.find("(");
+ int secondBrace = current.find(")");
TQString wallclockValue = current.mid(firstBrace + 1, secondBrace - firstBrace - 2);
kdDebug() << "WALLCLOCK VALUE " << wallclockValue << endl;
}
- else if(current.tqcontains("."))
+ else if(current.contains("."))
{
- int dotPosition = current.tqfind(".");
+ int dotPosition = current.find(".");
TQString element = current.mid(0, dotPosition);
TQString clockValue;
- if(current.tqcontains("begin"))
+ if(current.contains("begin"))
clockValue = current.mid(dotPosition + 6);
- else if(current.tqcontains("end"))
+ else if(current.contains("end"))
clockValue = current.mid(dotPosition + 4);
- else if(current.tqcontains("repeat"))
+ else if(current.contains("repeat"))
clockValue = current.mid(dotPosition + 7);
else // DOM2 Event Reference
{
int plusMinusPosition = -1;
- if(current.tqcontains("+"))
- plusMinusPosition = current.tqfind("+");
- else if(current.tqcontains("-"))
- plusMinusPosition = current.tqfind("-");
+ if(current.contains("+"))
+ plusMinusPosition = current.find("+");
+ else if(current.contains("-"))
+ plusMinusPosition = current.find("-");
TQString event = current.mid(dotPosition + 1, plusMinusPosition - dotPosition - 1);
@@ -405,9 +405,9 @@ void SVGAnimationElementImpl::setAttributes()
{
SVGElementImpl::setAttributes();
// Spec: Default value is "tqreplace"
if(KSVG_TOKEN_NOT_PARSED(Additive))
- KSVG_SET_ALT_ATTRIBUTE(Additive, "tqreplace")
+ KSVG_SET_ALT_ATTRIBUTE(Additive, "replace")
// Spec: Default value is "none"
if(KSVG_TOKEN_NOT_PARSED(Accumulate))
@@ -405,9 +405,9 @@ void SVGAnimationElementImpl::setAttributes()
{
SVGElementImpl::setAttributes();
- // Spec: Default value is "tqreplace"
+ // Spec: Default value is "replace"
if(KSVG_TOKEN_NOT_PARSED(Additive))